"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _extend = _interopRequireDefault(require("extend"));

var _process = _interopRequireDefault(require("process"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param argv {config, debug, synchronize, environment}
 * @param Deployer
 */
function _default(argv, Deployer) {
  if (!argv.config) {
    argv.config = 'deployment-config.js';
  } // Load config file


  const rawConfiguration = readConfigurationFile(argv.config, argv);
  const configuration = mergeConfiguration(rawConfiguration, argv.environment);

  if (argv.synchronize) {
    configuration.mode = 'synchronize';
  } // Show debug


  if (argv.debug) {
    configuration.debug = true;
  } // Deploy


  const deployer = new Deployer(configuration); // Return public API

  return {
    deploy: () => deployer.deployRelease(),
    remove: () => deployer.removeRelease(),
    rollback: () => deployer.rollbackToPreviousRelease()
  };
}
/**
 * Return absolute filePath
 * if filePath is not an absolute path, will prepend with process.cwd
 * @param filePath
 * @return {string|*}
 */


function getAbsoluteFilePath(filePath) {
  if (_path.default.isAbsolute(filePath)) {
    return filePath;
  }

  return _path.default.join(_process.default.cwd(), filePath);
}
/**
 * Read configuration file
 * @param filePath
 * @param argv
 * @return {*}
 */


function readConfigurationFile(filePath, argv) {
  const absoluteFilePath = getAbsoluteFilePath(filePath);

  if (!_fs.default.existsSync(absoluteFilePath)) {
    throw 'Configuration file not found "' + absoluteFilePath + '"';
  }

  const rawConfiguration = require(absoluteFilePath)({
    get: key => argv[key]
  });

  return (0, _extend.default)({
    common: {},
    environments: {}
  }, rawConfiguration);
}
/**
 * Merge common and environment configuration
 * @param rawConfiguration
 * @param environment
 * @return {}
 */


function mergeConfiguration(rawConfiguration, environment) {
  if (!rawConfiguration.environments[environment]) {
    throw 'Environment "' + environment + '" not found in configuration';
  }

  return (0, _extend.default)({}, rawConfiguration.common, rawConfiguration.environments[environment]);
}