#!/usr/bin/env node
"use strict";

var _Deployator = _interopRequireDefault(require("./Deployator"));

var _sshDeployRelease = _interopRequireDefault(require("ssh-deploy-release"));

var _yargs = _interopRequireDefault(require("yargs"));

var _initializeConfiguration = _interopRequireDefault(require("./initialize-configuration"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const argv = _yargs.default.command({
  command: 'deploy [--config] [--environment] [--debug] [--synchronize]',
  desc: 'Deploy release to the remote server',
  handler: argv => {
    const deployator = new _Deployator.default(argv, _sshDeployRelease.default);
    deployator.deploy();
  }
}).command({
  command: 'remove [--config] [--environment] [--debug]',
  desc: 'Deploy release to the remote server',
  handler: argv => {
    const deployator = new _Deployator.default(argv, _sshDeployRelease.default);
    deployator.remove();
  }
}).command({
  command: 'rollback',
  desc: 'Rollback to the previous release',
  handler: argv => {
    const deployator = new _Deployator.default(argv, _sshDeployRelease.default);
    deployator.rollback();
  }
}).command({
  command: 'init [--config]',
  desc: 'Initialize configuration file',
  handler: argv => {
    (0, _initializeConfiguration.default)(argv.config);
  }
}).demandCommand().option('config', {
  alias: 'c',
  describe: 'path of configuration file'
}).option('environment', {
  alias: 'e',
  describe: 'environment name (example: review, preproduction)'
}).option('debug', {
  alias: 'd',
  describe: 'Enable debug mode',
  boolean: true
}).option('synchronize', {
  alias: 's',
  describe: 'Enable synchronize mode',
  boolean: true
}).help().showHelpOnFail().argv;